import fs from 'node:fs';
import { Options } from './options.js';
import { Template } from './template.js';
import * as logger from './logger.js';
const log = logger.create();
export class TemplateService {
    options = new Options();
    templates = new Array();
    constructor(options) {
        this.options = new Options(options);
        this.loadTemplates();
    }
    loadTemplates() {
        this.templates = new Array();
        if (fs.existsSync(this.options.TEMPLATE_PATH)) {
            const templateDirectories = fs.readdirSync(this.options.TEMPLATE_PATH);
            for (const templateDirectoryPath of templateDirectories) {
                const templatePath = `${String(this.options.TEMPLATE_PATH)}/${String(templateDirectoryPath)}`;
                const template = new Template(templatePath);
                this.templates.push(template);
            }
        }
        else {
            log.error(`The template path does not exist: ${String(this.options.TEMPLATE_PATH)}`);
        }
    }
    getTemplate(templateName) {
        for (const template of this.templates) {
            if (template.name === templateName) {
                return template;
            }
        }
        return undefined;
    }
}
//# sourceMappingURL=template-service.js.map